@@ -23,10 +23,10 @@ class RxnDataUtils:
         self._rxn_df = self._rxn_df.sample(frac=1)
         for _, row in self._rxn_df.iterrows():
             rxn = Rxn.init_from_series(row)
-            rxn.reactants = [self._mol_data_utils.get_mol_with_code(mol_code) for mol_code in rxn.reactants_codes]
+            rxn.reactants = [self._mol_data_utils.get_mol_with_code(mol_code) for mol_code in eval(rxn.reactants_codes)]
             rxn.products = [self._mol_data_utils.get_mol_with_code(rxn.product_code)]
-            rxn.catalysts = [self._mol_data_utils.get_mol_with_code(mol_code) for mol_code in rxn.catalysts_codes]
-            rxn.solvents = [self._mol_data_utils.get_mol_with_code(mol_code) for mol_code in rxn.solvents_codes]
+            rxn.catalysts = [self._mol_data_utils.get_mol_with_code(mol_code) for mol_code in eval(rxn.catalysts_codes)]
+            rxn.solvents = [self._mol_data_utils.get_mol_with_code(mol_code) for mol_code in eval(rxn.solvents_codes)]
             yield rxn
 
 
